tomboy r2049 - in trunk: . extra/firefox-extension
- From: sharm svn gnome org
- To: svn-commits-list gnome org
- Subject: tomboy r2049 - in trunk: . extra/firefox-extension
- Date: Fri, 1 Aug 2008 22:28:14 +0000 (UTC)
Author: sharm
Date: Fri Aug 1 22:28:14 2008
New Revision: 2049
URL: http://svn.gnome.org/viewvc/tomboy?rev=2049&view=rev
Log:
* extra/firefox-extension/build.sh: Support building from an SVN
working copy (removed unneeded CVS support).
Modified:
trunk/ChangeLog
trunk/extra/firefox-extension/build.sh
Modified: trunk/extra/firefox-extension/build.sh
==============================================================================
--- trunk/extra/firefox-extension/build.sh (original)
+++ trunk/extra/firefox-extension/build.sh Fri Aug 1 22:28:14 2008
@@ -64,11 +64,11 @@
mkdir --parents --verbose $TMP_DIR/chrome
# generate the JAR file, excluding CVS and temporary files
JAR_FILE=$TMP_DIR/chrome/$APP_NAME.jar
echo "Generating $JAR_FILE..."
for CHROME_SUBDIR in $CHROME_PROVIDERS; do
- find $CHROME_SUBDIR -path '*CVS*' -prune -o -type f -print | grep -v \~ >> files
+ find $CHROME_SUBDIR -path '*/.svn/*' -prune -o -type f -print | grep -v \~ >> files
done
zip -0 -r $JAR_FILE `cat files`
@@ -79,7 +79,7 @@
echo "Copying various files to $TMP_DIR folder..."
for DIR in $ROOT_DIRS; do
mkdir $TMP_DIR/$DIR
- FILES="`find $DIR -path '*CVS*' -prune -o -type f -print | grep -v \~`"
+ FILES="`find $DIR -path '*/.svn/*' -prune -o -type f -print | grep -v \~`"
echo $FILES >> files
cp --verbose --parents $FILES $TMP_DIR
done
@@ -64,11 +64,11 @@
mkdir --parents --verbose $TMP_DIR/chrome
-# generate the JAR file, excluding CVS and temporary files
+# generate the JAR file, excluding SVN and temporary files
JAR_FILE=$TMP_DIR/chrome/$APP_NAME.jar
echo "Generating $JAR_FILE..."
[
Date Prev][
Date Next] [
Thread Prev][
Thread Next]
[
Thread Index]
[
Date Index]
[
Author Index]